from test.TestBase import WorldTestBase
from ..constants import game_name


class BfBBTestBase(WorldTestBase):
    game = game_name
